Documentation
¶
Index ¶
Constants ¶
const ( Unset mark = iota Starred Primed )
Munkres Code
Variables ¶
This section is empty.
Functions ¶
func GetMunkresMinScore ¶
func GetMunkresMinScore(m *FloatMatrix) float64
GetMunkresMinScore returns the sum of the elements that comprise the lowest cost path
Types ¶
type FloatMatrix ¶
FloatMatrix Code
func NewMatrix ¶
func NewMatrix(n int64) (m *FloatMatrix)
NewMatrix will return a pointer to a new FloatMatrix
func (FloatMatrix) GetElement ¶
func (m FloatMatrix) GetElement(i int64, j int64) float64
GetElement will return the element of the matrix at position (i,j)
func (FloatMatrix) SetElement ¶
func (m FloatMatrix) SetElement(i int64, j int64, v float64)
SetElement will set the element of the matrix at position (i,j)
Click to show internal directories.
Click to hide internal directories.